from l10n_ar_api.padron import banks
import unittest
import sys
import random

sys.path.append("../")


class TestContribuyentes(unittest.TestCase):

    def setUp(self):
        self.banks_list = banks.Banks.get_banks_list()
        self.values = banks.Banks.get_values(self.banks_list)
        
    def test_check_values_types(self):
        values = [self.values[0], self.values[-1], random.choice(self.values)]
        for bank in values:
            int(bank['cuit'])
            int(bank['code'])

    def test_check_invalid_values_types(self):
        values = [self.values[0], self.values[-1], random.choice(self.values)]
        for bank in values:
            int(bank['cuit'])
            int(bank['code'])
            self.assertRaises(ValueError, lambda: int(bank['name']))


if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages
import sys

install_requires = [
    'zeep==2.5.0',
    'python-dateutil',
    'M2Crypto',
    'pytz',
    'unidecode',
    'requests',
    'lxml',
    'qrcode'
]

if sys.version_info[0] >= 3:
    install_requires.append('bs4')
else:
    install_requires.append('BeautifulSoup')

setup(
    name='l10n_ar_api',
    version='2.1.12',
    description='Libreria para localizacion Argentina',
    long_description='Libreria para localizacion Argentina',
    url='https://github.com/odoo-arg/l10n_ar_api',
    author='BLUEORANGE GROUP SRL',
    author_email='daniel@blueorange.com.ar',
    license='',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    keywords='Libreria para localizacion Argentina',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    install_requires=install_requires,
    extras_require={},
    package_data={},
    data_files=[],
    entry_points={},
)
